Skip to contents

Opens an interactive Shiny app for exploring how group means, within-group variation, and sample size affect a one-way ANOVA.

Usage

run_anova_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Value

run_anova_app() opens the Shiny app locally.

Details

All data are simulated in R via rnorm().

Examples

if (FALSE) { # interactive()
run_anova_app()
}