Opens an interactive Shiny app for exploring how group means, within-group variation, and sample size affect a one-way ANOVA.
Arguments
- ...
Optional arguments passed to
shiny::runApp(). By default, statsapps opens apps in the system default web browser usinglaunch.browser = TRUE. Uselaunch.browser = FALSEto disable this behavior.
Details
All data are simulated in R via rnorm().