Opens an interactive Shiny app for exploring common probability distributions used in BIOL 300.
Arguments
- ...
Optional arguments passed to
shiny::runApp(). By default, statsapps opens apps in the system default web browser usinglaunch.browser = TRUE. Uselaunch.browser = FALSEto disable this behavior.