Opens an interactive Shiny app for exploring common probability distributions used in BIOL 300.
Arguments
- ...
Optional arguments passed to
shiny::runApp(), such aslaunch.browser = TRUE. Most users can ignore this.
Opens an interactive Shiny app for exploring common probability distributions used in BIOL 300.
Optional arguments passed to shiny::runApp(), such as
launch.browser = TRUE. Most users can ignore this.