Opens an interactive Shiny app for exploring how the slope and intercept of a linear model affect fitted values and residuals.
Arguments
- ...
Optional arguments passed to
shiny::runApp(). By default, statsapps opens apps in the system default web browser usinglaunch.browser = TRUE. Uselaunch.browser = FALSEto disable this behavior.