Opens an interactive Shiny app for exploring how the slope and intercept of a linear model affect fitted values and residuals.
Arguments
- ...
Optional arguments passed to
shiny::runApp(), such aslaunch.browser = TRUE. Most users can ignore this.
Opens an interactive Shiny app for exploring how the slope and intercept of a linear model affect fitted values and residuals.
Optional arguments passed to shiny::runApp(), such as
launch.browser = TRUE. Most users can ignore this.