Opens an interactive Shiny app for exploring how total variation can be partitioned into group-level and within-group components in one-way ANOVA.
Arguments
- ...
Optional arguments passed to
shiny::runApp(). By default, statsapps opens apps in the system default web browser usinglaunch.browser = TRUE. Uselaunch.browser = FALSEto disable this behavior.